# remirepo spec file for php-pecl-luasandbox
#
# SPDX-FileCopyrightText:  Copyright 2015-2025 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#

%{?scl:%scl_package php-pecl-luasandbox}

%bcond_without      tests

%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global proj_name   LuaSandbox
%global pecl_name   luasandbox
%global ini_name    40-%{pecl_name}.ini
%global sources     %{proj_name}-%{version}
%global _configure  ../%{sources}/configure

Summary:        Lua interpreter with limits and safe environment
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        4.1.2
Release:        2%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:        MIT
URL:            https://pecl.php.net/package/%{proj_name}
Source0:        https://pecl.php.net/get/%{sources}.tgz

Patch0:         0001-use-zend_ce_exception-instead-of-zend_exception_get_.patch

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel >= 7.2
BuildRequires:  %{?scl_prefix}php-pear
# version 5.1 required
BuildRequires:  compat-lua-devel

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{proj_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{proj_name})%{?_isa} = %{version}


%description
LuaSandbox is an extension for running untrusted Lua code within a
PHP web request. Code is run in a stripped-down, safe environment.
Time and memory limits can be set.


Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c

# Don't install tests
sed -e 's/role="test"/role="src"/' \
    -e '/COPYING/s/role="doc"/role="src"/' \
    -i package.xml

cd %{sources}
%patch -P0 -p1

: Sanity check, really often broken
extver=$(sed -n '/#define LUASANDBOX_VERSION /{s/.* "//;s/".*$//;p}' luasandbox_version.h)
if test "x${extver}" != "x%{version}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
# Duplicate source tree for NTS / ZTS build
mkdir ZTS
%endif

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

cd %{sources}
%{__phpize}

cd ../NTS
%configure \
    --with-luasandbox \
    --with-php-config=%{__phpconfig}
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%configure \
    --with-luasandbox \
    --with-php-config=%{__ztsphpconfig}
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
cd %{sources}

OPTS=" -q -P --show-diff"
%if "%{php_version}" > "8.0"
OPTS="$OPTS %{?_smp_mflags}"
%endif

: ignore test with erratic results
rm tests/profiler.phpt

: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep -i '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite for NTS extension
TEST_PHP_ARGS="-n -d extension=$PWD/../NTS/modules/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php $OPTS
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep -i '^%{pecl_name}$'

: Upstream test suite for ZTS extension
%if %{with tests}
TEST_PHP_ARGS="-n -d extension=$PWD/../ZTS/modules/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php $OPTS
%endif
%endif


%files
%doc %{pecl_docdir}/%{pecl_name}
%license %{sources}/COPYING

%{pecl_xmldir}/%{name}.xml
%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Thu Jul 17 2025 Remi Collet <remi@remirepo.net> - 4.1.2-2
- add fix for PHP 8.5.0alpha2, patch sent to author
- re-license spec file to CECILL-2.1

* Wed Dec 13 2023 Remi Collet <remi@remirepo.net> - 4.1.2-1
- update to 4.1.2

* Wed Aug 30 2023 Remi Collet <remi@remirepo.net> - 4.1.1-2
- rebuild for PHP 8.3.0RC1

* Mon Jul 31 2023 Remi Collet <remi@remirepo.net> - 4.1.1-1
- update to 4.1.1
- build out of sources tree

* Fri Sep 23 2022 Remi Collet <remi@remirepo.net> - 4.1.0-1
- update to 4.1.0

* Tue Sep 20 2022 Remi Collet <remi@remirepo.net> - 4.0.2-2
- add upstream patch for 8.2

* Wed May 19 2021 Remi Collet <remi@remirepo.net> - 4.0.2-1
- update to 4.0.2 (no change)

* Wed Mar 10 2021 Remi Collet <remi@remirepo.net> - 4.0.1-1
- update to 4.0.1 (no change)

* Thu Mar  4 2021 Remi Collet <remi@remirepo.net> - 4.0.0-1
- update to 4.0.0
- raise dependency on PHP 7.2

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 3.0.3-4
- rebuild for 7.4.0RC1

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 3.0.3-3
- rebuild for 7.4.0beta1

* Thu Jan 17 2019 Remi Collet <remi@remirepo.net> - 3.0.3-2
- ignore 1 test with erratic results

* Thu Oct 11 2018 Remi Collet <remi@remirepo.net> - 3.0.3-1
- update to 3.0.3
- drop patch merged upstream

* Tue Oct  9 2018 Remi Collet <remi@remirepo.net> - 3.0.2-1
- initial package, version 3.0.2 (stable)
- add patch to fix ZTS build with PHP 7+
